Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/typedconfig/__about__.py | 1 | 0 | 0 | 100%
src/typedconfig/__init__.py | 3 | 0 | 0 | 100%
src/typedconfig/cls.py | 7 | 0 | 0 | 100%
src/typedconfig/core.py | 142 | 0 | 3 | 100%
src/typedconfig/errors.py | 26 | 0 | 0 | 100%
src/typedconfig/helpers.py | 2 | 0 | 0 | 100%
src/typedconfig/loaders/__init__.py | 4 | 0 | 2 | 100%
src/typedconfig/loaders/loaders_310.py | 5 | 0 | 6 | 100%
src/typedconfig/loaders/loaders_311.py | 6 | 0 | 2 | 100%
src/typedconfig/singleton.py | 13 | 0 | 0 | 100%
Total | 209 | 0 | 13 | 100%

No items found using the specified filter.